@@ -6,3 +6,8 @@ from ._helpers import current_app, flash, get_session_messages
 from .response import redirect
 
 from .templating import render_template, render_string
+from.routing import url_for
+
+
+__version__ = '0.0.3'
+
