@@ -38,7 +38,7 @@ class Template:
         """Render template"""
         if self._compiled_nodes is None:
             self.compile()
-        context.update(self.context)
+        self.context.update(context)
         return self._compiled_nodes.render(context, self.env)
 
     def add_tags(self, tags):
@@ -151,7 +151,12 @@ class Environment:
     :param loader: template loader class to load templates.
     :param filters: dict of custom filters.
     '''
-    def __init__(self, cache=None, tags=None, filters=None, loader=None, **options):
+    def __init__(self,
+                 cache=None,
+                 tags=None,
+                 filters=None,
+                 loader=None,
+                 **options):
 
         self.cache = cache
         # self.options = options
